#
# spec file for package openSUSE-build-key
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needspubkeyforbuild


%define keydir  %{_prefix}/lib/rpm/gnupg/keys/
%define containerkeydir  %{_datadir}/container-keys/
%define pemcontainerkeydir  /%{_datadir}/pki/containers/

Name:           openSUSE-build-key
Version:        1.0
Release:        59.1
Summary:        The public gpg keys for rpm package signature verification
License:        GPL-2.0-or-later
Group:          System/Packages
URL:            https://en.opensuse.org/openSUSE:Security_team
Source:         key2rpmname
# opensuse@opensuse.org
# old 2048 key now no longer used
# Source1:        gpg-pubkey-3dbdc284-53674dd4.asc
Obsoletes:      gpg-pubkey-3dbdc284
# old global openSUSE key, was errnously used for Slowroll
Obsoletes:      gpg-pubkey-eae4fd92

# openSUSE RSA 4096 key
Source10:       gpg-pubkey-29b700a4-62b07e22.asc

# build@suse.de for SLE12 / SLE15
Source2:        gpg-pubkey-39db7c82-66c5d91a.asc

# RISCV
Source3:        gpg-pubkey-697ba1e5-5c755904.asc

# zSystems
Source5:        gpg-pubkey-f6ab3975-62e9e6fb.asc

# PowerPC
Source6:        gpg-pubkey-8ede3e07-5c755f3a.asc

# Container key openSUSE
Source7:        opensuse-container-9ab48ce9-5ae3116a.asc

# Container key SUSE Linux Enterprise
Source8:        build-container-d4ade9c3-5a2e9669.asc
# openSUSE Backports key (previously PackageHub, now also Leap 15.6)
Source9:        gpg-pubkey-25db7ae0-645bae34.asc
# obsoletes old RSA 2k backports key
Obsoletes:      gpg-pubkey-65176565

# openSUSE Backports key for SLE 16.0
Source20:       gpg-pubkey-287a0027-682477e3.asc

# Container key SUSE Linux Enterprise in PEM format
Source11:       build-container-d4ade9c3-5a2e9669.pem

# 2023 Container key openSUSE in PEM and GPG formats
Source12:       build-container-202304-d684afec-64390cff.pem
Source13:       build-container-202304-d684afec-64390cff.asc

# 2023 Container key SUSE in PEM and GPG formats
Source14:       build-container-8fd6c337-63c94b45.pem
Source15:       build-container-8fd6c337-63c94b45.asc

# SLM 6.0 key (SLM 6/ SLES 16) RSA 4096 bit key
Source16:       gpg-pubkey-09d9ea69-68595a8c.asc
# 2024 SUSE Linux Enterprise 15 SP6 RSA 4096 bit key
Source17:       gpg-pubkey-3fa1d6ce-67c856ee.asc
# SLM 6.0 key (ALP / SLF1) RSA 4096 bit reserve key
Source18:       gpg-pubkey-73f03759-626bd414.asc
# 2024 SUSE Linux Enterprise 15 SP6 RSA 4096 bit reserve key
Source19:       gpg-pubkey-d588dc46-63c939db.asc

Source98:       security_at_suse_de.asc

# Auto Import handling via systemd timer + service.
# Needed in Leap currently, but also have it here.
Source101:      import-openSUSE-build-key
Source102:      %name-import.service
Source103:      %name-import.timer

BuildRequires:  gpg
Conflicts:      suse-build-key
Provides:       build-key = %{version}
BuildRequires:  systemd-rpm-macros

# Old 1024 bit RSA key for SLE11.
Obsoletes:      gpg-pubkey = 307e3d54-5aaa90a5

%description
This package contains the gpg keys that are used to sign the
openSUSE rpm packages. The keys installed here are not actually
used by anything. rpm/zypper use the keys in the rpm db instead.

%prep
%setup -qcT

%build
cp %{SOURCE98} .
%ifarch riscv64
cp %{SOURCE3} .
%endif
%ifarch s390 s390x
cp %{SOURCE5} .
%endif
%ifarch ppc ppc64 ppc64le
cp %{SOURCE6} .
%endif
cp %{SOURCE16} .
cp %{SOURCE17} .

%install
mkdir -p %{buildroot}%{keydir}
for i in %{SOURCE20} %{SOURCE10} %{SOURCE2} \
%if 0%{?sle_version}
%{SOURCE9} \
%endif
%ifarch riscv64
%{SOURCE3} \
%endif
%ifarch s390 s390x
%{SOURCE5} \
%endif
%ifarch ppc ppc64 ppc64le
%{SOURCE6} \
%endif
%{SOURCE16} \
%{SOURCE17} \
; do
    case "$i" in
	*/gpg-pubkey-*.asc)
	install -m 644 "$i" %{buildroot}%{keydir}
	;;
    esac
done
mkdir -p %{buildroot}%{containerkeydir}/
install -c -m 644 %{SOURCE7} %{buildroot}%{containerkeydir}/opensuse-container-key.asc
install -c -m 644 %{SOURCE8} %{buildroot}%{containerkeydir}/suse-container-key-old.asc
install -c -m 644 %{SOURCE15} %{buildroot}%{containerkeydir}/suse-container-key.asc
install -c -m 644 %{SOURCE13} %{buildroot}%{containerkeydir}/opensuse-container-key-2023.asc
mkdir -p %{buildroot}%{pemcontainerkeydir}/
install -c -m 644 %{SOURCE14} %{buildroot}%{pemcontainerkeydir}/suse-container-key.pem
install -c -m 644 %{SOURCE11} %{buildroot}%{pemcontainerkeydir}/suse-container-key-old.pem
install -c -m 644 %{SOURCE12} %{buildroot}%{pemcontainerkeydir}/opensuse-container-key-2023.pem
if [ -e "%_sourcedir/_pubkey" ]; then
    name="$(sh %{SOURCE0} %_sourcedir/_pubkey).asc"
    if [ ! -e "%_sourcedir/$name" ]; then
	install -D -m 644 %_sourcedir/_pubkey %{buildroot}%keydir/"$name"
    fi
fi

mkdir -p $RPM_BUILD_ROOT/usr/sbin/
mkdir -p $RPM_BUILD_ROOT/var/lib/%name
install -m 755 %{SOURCE101} $RPM_BUILD_ROOT/usr/sbin/import-%name
mkdir -p $RPM_BUILD_ROOT/%_unitdir
install -m 644 %{SOURCE102} $RPM_BUILD_ROOT/%_unitdir/
install -m 644 %{SOURCE103} $RPM_BUILD_ROOT/%_unitdir/

%post
: >/var/lib/%{name}/imported
%service_add_post openSUSE-build-key-import.service openSUSE-build-key-import.timer
test -x /usr/bin/systemctl && systemctl enable openSUSE-build-key-import.timer && systemctl start openSUSE-build-key-import.timer || true

%pre
%service_add_pre openSUSE-build-key-import.service openSUSE-build-key-import.timer

%preun
%service_del_preun openSUSE-build-key-import.service openSUSE-build-key-import.timer

%postun
%service_del_postun openSUSE-build-key-import.service openSUSE-build-key-import.timer

%files
%defattr(644,root,root)
%doc security_at_suse_de.asc
%attr(755,root,root) %dir %{_prefix}/lib/rpm/gnupg
%attr(755,root,root) %dir %{keydir}
%attr(755,root,root) %dir %{containerkeydir}
%attr(755,root,root) %dir %{_datadir}/pki/
%attr(755,root,root) %dir %{pemcontainerkeydir}
%{keydir}/gpg-pubkey-*.asc
%{containerkeydir}/opensuse-container-key.asc
%{containerkeydir}/suse-container-key.asc
%{containerkeydir}/suse-container-key-old.asc
%{containerkeydir}/opensuse-container-key-2023.asc
%{pemcontainerkeydir}/suse-container-key.pem
%{pemcontainerkeydir}/suse-container-key-old.pem
%attr(755,root,root) %_sbindir/import-%name
%{pemcontainerkeydir}/opensuse-container-key-2023.pem
%dir /var/lib/%{name}
%ghost /var/lib/%{name}/imported
%_unitdir/%name-import.service
%_unitdir/%name-import.timer

%changelog
* Fri Jul 11 2025 Marcus Meissner <meissner@suse.com>
- gpg-pubkey-09d9ea69-68595a8c.asc: renamed uid field to not
  use outdated internal codenames. (bsc#1245223)
* Mon May 26 2025 Marcus Meissner <meissner@suse.com>
- added gpg-pubkey-287a0027-682477e3.asc: New RSA 4k Backports
  for SLE 16.x series.
* Tue May 13 2025 Marcus Meissner <meissner@suse.com>
- added gpg-pubkey-25db7ae0-645bae34.asc: RSA 4k SLE15 Backports key.
- removed gpg-pubkey-65176565-61a0ee8f.asc: old RSA 2k Backports key.
  (bsc#1243135)
* Tue Mar 11 2025 Marcus Meissner <meissner@suse.com>
- gpg-pubkey-39db7c82-66c5d91a.asc: extended lifetime of SLE12 / 15
  2048 bit key.
* Wed Mar  5 2025 Marcus Meissner <meissner@suse.com>
- changed keys to use SHA256 UIDs instead of SHA1. (bsc#1237294
  bsc#1236779 jsc#PED-12321)
  - gpg-pubkey-3fa1d6ce-67c856ee.asc to gpg-pubkey-09d9ea69-67c857f3.asc
  - gpg-pubkey-09d9ea69-645b99ce.asc to gpg-pubkey-3fa1d6ce-63c9481c.asc
* Fri Jun 21 2024 Lubos Kocman <Lubos.Kocman@suse.com>
- Ensure that SLM 6.0 key is installed on Leap Micro and Leap 16
- install SLFO / SLM 6.0 key and SLES 15 SP6+ key by default
* Wed Apr 10 2024 Marcus Meissner <meissner@suse.com>
- SLM 6.0 key (ALP / SLF1) RSA 4096 bit key
  - gpg-pubkey-09d9ea69-645b99ce.asc
- 2024 SUSE Linux Enterprise 15 SP6 RSA 4096 bit key
  - gpg-pubkey-3fa1d6ce-63c9481c.asc
- SLM 6.0 key (ALP / SLF1) RSA 4096 bit reserve key
  - gpg-pubkey-73f03759-626bd414.asc
- 2024 SUSE Linux Enterprise 15 SP6 RSA 4096 bit reserve key
  - gpg-pubkey-d588dc46-63c939db.asc
- obsoleted a incorrectly used DSA1024 key (used in Slowroll).
* Tue Mar 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Fix import-openSUSE-build-key:set proper timer name to try to
  stop (openSUSE-build-key-import.timer, not
  suse-build-key-import.timer) (boo#1221948).
* Sun Mar 24 2024 Giacomo Comes <gcomes.obs@gmail.com>
- Requires(post): coreutils is missing
  * instead of adding it, change the post scriptlet:
    do not use touch, use shell redirection
* Thu Mar 14 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Install import-openSUSE-build-key to %%{_sbindir}: align to where
  the .service file is launching the script from (boo#1221427).
* Wed Mar  6 2024 Marcus Meissner <meissner@suse.com>
- add unexpired openSUSE zSystems key (bsc#1220993)
  - replace gpg-pubkey-f6ab3975-5edd7d4f.asc
  - by gpg-pubkey-f6ab3975-62e9e6fb.asc
* Mon Feb 19 2024 Marcus Meissner <meissner@suse.com>
- added new suse container key, moved the old one to -old
* Tue Jun  6 2023 Marcus Meissner <meissner@suse.com>
- openSUSE-build-key-import.service,openSUSE-build-key-import.service.timer,
  import-openSUSE-build-key:
  Add systemd timer and service framework that imports new keys.
* Fri Apr 14 2023 Marcus Meissner <meissner@suse.com>
- Added a new 4096 openSUSE container key
  - build-container-202304-d684afec-64390cff.asc
  - build-container-202304-d684afec-64390cff.pem
- Removed and obsoleted old 2048 build key of Tumbleweed
  - gpg-pubkey-3dbdc284-53674dd4.asc
* Mon Dec  5 2022 Ludwig Nussel <lnussel@suse.de>
- Package OBS project key if available. Useful when forking
  openSUSE-build-key for use in appliances.
* Tue Oct 25 2022 Marcus Meissner <meissner@suse.com>
- add the SUSE Container key in PEM format too to new
  /usr/share/pki/containers/ directory. (bsc#1204706)
* Wed Aug 10 2022 Dirk Müller <dmueller@suse.com>
- add gpg-pubkey-29b700a4-62b07e22.asc (bsc#1199184)
* Thu Mar 24 2022 Marcus Meissner <meissner@suse.com>
- gpg-pubkey-307e3d54-5aaa90a5 is actually "package gpg-pubkey,
  version-release 307e3d54-5aaa90a5"
* Fri Mar 18 2022 Marcus Meissner <meissner@suse.com>
- gpg-pubkey-307e3d54-5aaa90a5.asc: remove the RSA 1024bit SLE11 key
  and try to remove it from installed systems via Obsoletes.
* Fri Jan 14 2022 Marcus Meissner <meissner@suse.com>
- refresh the openSUSE Backports key (bsc#1193092)
  - gpg-pubkey-65176565-59787af5.asc
  + gpg-pubkey-65176565-61a0ee8f.asc
- removed old security key
- updated security key to 2020 version
* Mon Sep 27 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Only add openSUSE Backports key when building for a Leap system
  (sle_version > 0). Tumbleweed does not use Backports.
* Fri Jun 11 2021 Dirk Müller <dmueller@suse.com>
- remove dumpsigs, unused since SLE12+ (rpm 4.x) (bsc#1186827)
* Fri Jun 11 2021 Dirk Müller <dmueller@suse.com>
- add URL
- spec-cleaner run
* Sat Jun  5 2021 Neal Gompa <ngompa13@gmail.com>
- Merge changes from openSUSE Leap 15.3 for rpm-repos-openSUSE (boo#1186593)
* Fri May 21 2021 Yuchen Lin <mlin+factory@suse.de>
- Refresh the SLE15 build@suse.de key
  * Updated gpg-pubkey-39db7c82-5847eb1f.asc
* Sat Apr 24 2021 Marcus Meissner <meissner@suse.com>
- fixed s390x key install (bsc#1185245)
* Thu Jan 28 2021 Lubos Kocman <lubos.kocman@suse.com>
- Add openSUSE Backports key to openSUSE Leap (bsc#1181344)
  This is needed because most of Leap 15.3+ packages are in fact
  build in openSUSE Backport (Closing The Leap Gap)
* Fri Jan  8 2021 Dirk Müller <dmueller@suse.com>
- update openSUSE:Factory:zSystems signing key to current version:
  pub   rsa2048 2016-02-17 [SC] [expires: 2022-08-16]
    F00C20EF1E1114C9B5F69B2276CA4244F6AB3975
  openSUSE:Factory:zSystems OBS Project <openSUSE:Factory:zSystems@build.opensuse.org>
* Tue Sep 22 2020 Marcus Meissner <meissner@suse.com>
- the container keys for openSUSE and SUSE Linux Enterprise are actually
  not the build keys. (bsc#1176818)
- build@suse.de key for SLE12 was extended. (bsc#1176759)
* Mon Apr 27 2020 Thorsten Kukuk <kukuk@suse.com>
- Remove PreRequires for removed post section with outdated
  package names.
* Thu Apr 23 2020 Marcus Meissner <meissner@suse.com>
- use /usr/share/container-keys/ for container keys.
* Thu Apr  2 2020 Marcus Meissner <meissner@suse.com>
- mark the opensuse-container-key and the suse-container-key
  for openSUSE:Containers and SUSE:Containers space.
  (same as the build keys for SLE15 and openSUSE respectively.)
- Replace the old security@suse.de email comm key by the new, move
  the old one to the oldkey. (bsc#1166334)
* Mon Mar 25 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix previous commit
* Tue Mar  5 2019 Adrian Schröter <adrian@suse.de>
- drop arm specific key again
  => ARM sub project is considered to be equal trustworthy
* Tue Feb 26 2019 Adrian Schröter <adrian@suse.de>
- add project keys for architecture ports projects
  gpg-pubkey-bbac6b14-5c755908.asc: openSUSE:Factory:ARM
  gpg-pubkey-697ba1e5-5c755904.asc: openSUSE:Factory:RISCV
  gpg-pubkey-8ede3e07-5c755f3a.asc: openSUSE:Factory:PowerPC
  gpg-pubkey-f6ab3975-5ad08cb7.asc: openSUSE:Factory:zSystems
- package needs to become arch specific again to avoid the import
  of foreign ports projects
* Wed Mar 28 2018 meissner@suse.com
- refreshed the SLE11 build@suse.de key (bsc#1085512)
- added the SLE12 and SLE15 build@suse.de key (bsc#1087276)
  gpg-pubkey-39db7c82-5847eb1f.asc
  pub   rsa2048/0x70AF9E8139DB7C82 2013-01-31 [SC] [expires: 2020-12-06]
    Key fingerprint = FEAB 5025 39D8 46DB 2C09  61CA 70AF 9E81 39DB 7C82
  uid                             SuSE Package Signing Key <build@suse.de>
- A new security@suse.de key has been established. (bsc#1082022)
* Tue Nov 29 2016 ro@suse.de
- modify dumpsigs to deal with fingerprint lines in gpg output
* Thu Oct  2 2014 meissner@suse.com
- renamed security_at_suse_de.asc to security_at_suse_de_old.asc
- security_at_suse_de.asc: new 4096 bit RSA key.
  pub  4096R/317CD502 2014-10-02 SUSE Security Team <security@suse.de>
  bnc#899509
* Thu May 22 2014 adrian@suse.de
- replace openSUSE gpg key with extended key.
* Wed Apr 18 2012 lnussel@suse.de
- install the security@suse.de key as %%doc for offline import
* Tue Apr 17 2012 lnussel@suse.de
- remove generated key rings, no longer needed by
  installation-images and linuxrc (bnc#724625)
- remove security@suse.de key, never used for package signing
- remove old build@suse.de key, was used on sle10
- remove openSUSE\x3aFactory@build.opensuse.org key, not used anymore
- leave sle11 build@suse.de key as backup
* Tue Oct 25 2011 lnussel@suse.de
- add /usr/lib/rpm/gnupg/suse-build-key.gpg again. Needed by
  installation-images and linuxrc.
* Fri Oct 21 2011 lnussel@suse.de
- remove no longer used keys from (bnc#724625)
- clean up packaging for easier maintenance
* Wed May  5 2010 ro@suse.de
- updated keys:
  - 307E3D54 build@suse.de "SuSE Package Signing Key" (2014-05-03)
  - 7E2E3B05 novell-provo-build@novell.com "Novell Provo Build"
    (2014-05-06)
  - 9C800ACA build@suse.de "SuSE Package Signing Key" (2014-05-03)
  - 56B4177A openSUSE:Factory@build.opensuse.org
    "openSUSE:Factory OBS Project" (2014-05-04)
  - 3DBDC284 opensuse@opensuse.org "openSUSE Project Signing Key"
    (2014-05-04)
* Mon Nov 10 2008 adrian@suse.de
- add the new openSUSE build key for real
* Fri Nov  7 2008 ro@suse.de
- added new openSUSE build key 2048R/3DBDC284 expiring 2010-11-07
* Thu Sep 18 2008 adrian@suse.de
- Branch package from suse-build-key and create it as openSUSE-build-key
- Add openSUSE:Factory key as official distribution key
* Mon Jun  2 2008 ro@suse.de
- update keys again: for collaboration with rpm, the current
  self-signature needs to be the first signature found in a key
* Mon May  5 2008 ro@suse.de
- updated keys
  9C800ACA,8495160C,307E3D54: extend expiration by 2 years
  until 2010-05-05
  7E2E3B05: extend expiration by 2 years until 2010-05-24
* Mon Mar 19 2007 rguenther@suse.de
- merge suse-build-key keyring to roots gpg pubring
* Mon May 29 2006 ro@suse.de
- added new official provo dsa autobuild key ID 7E2E3B05
* Fri May 19 2006 ro@suse.de
- removed unused provo autobuild key
- added new official provo autobuild key ID A1912208
* Thu Apr 20 2006 ro@suse.de
- add dumpsigs script here to have _one_ place for the script
* Fri Mar 31 2006 ro@suse.de
- added build@suse.de rsa key ID 307E3D54
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct 18 2005 ro@suse.de
- use correct provo autobuild key
* Tue Oct 18 2005 ro@suse.de
- added provo autobuild signing key (#128128)
- removed jds key
* Fri May 27 2005 mls@suse.de
- added mktemp to PreReqs [#86177]
* Thu Apr 28 2005 ro@suse.de
- added JDS public key (15c17deb)
* Tue Jan 25 2005 ro@suse.de
- added OES public key (0dfb3188)
* Tue Jun 22 2004 ro@suse.de
- updated build key (expiration changed to 2008-06-21) (#42326)
* Tue Feb 24 2004 hmacht@suse.de
- building as non-root
* Tue Sep  9 2003 ro@suse.de
- ignore return code from first gpg calls
* Tue Sep  9 2003 draht@suse.de
- call gpg twice without any arguments for proper initialization
  inside postinstall
* Tue Sep  9 2003 draht@suse.de
- use temp file instead of pipe due to resource race between two
  instances of gpg in %%post.
* Thu Sep  5 2002 draht@suse.de
- package now installs key from package-owned file into the rpm
  pubring in %%post to allow other key packages to add their keys.
* Tue Aug 20 2002 mmj@suse.de
- Correct PreReq
* Fri Jul 26 2002 kukuk@suse.de
- Change Provides from suse-build-key to build-key
* Wed Feb 20 2002 draht@suse.de
- directory permission problem: 644 -> 755.
* Mon Feb 18 2002 ro@suse.de
- moved to /usr/lib/rpm/gnupg/pubring.pgp
  rpm needs a directory as gpg_path and will use pubring.gpg
  in that directory
* Wed Feb 13 2002 draht@suse.de
- initial package. Contains
  - pub  2048R/3D25D3D9 1999-03-06 SuSE Security Team <security@suse.de>
  - pub  1024D/9C800ACA 2000-10-19 SuSE Package Signing Key <build@suse.de>
  - sub  2048g/8495160C 2000-10-19 [expires: 2006-02-12]
